aboutsummaryrefslogtreecommitdiffstats
path: root/internal/debug/api.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/debug/api.go')
-rw-r--r--internal/debug/api.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/internal/debug/api.go b/internal/debug/api.go
index 2cb264040..a0bff2768 100644
--- a/internal/debug/api.go
+++ b/internal/debug/api.go
@@ -131,9 +131,9 @@ func (h *HandlerT) StopCPUProfile() error {
return nil
}
// Trace turns on tracing for nsec seconds and writes
// trace data to file.
-func (h *HandlerT) Trace(file string, nsec uint) error {
+func (h *HandlerT) GoTrace(file string, nsec uint) error {
if err := h.StartTrace(file); err != nil {
return err
}
@@ -131,9 +131,9 @@ func (h *HandlerT) StopCPUProfile() error {
return nil
}
-// Trace turns on tracing for nsec seconds and writes
+// GoTrace turns on tracing for nsec seconds and writes
// trace data to file.